
<div class="chat-line" v-bind:class="[panelStyle]">
    <div class="panel-heading"> <span class="bold"> {{ name }} </span> - {{ timestamp }}</div>
    <div class="panel-body">
        <p>{{ text }}</p>
    </div>
</div>