/* BOOTSTRAP OVERRIDING */
.form-control.five-input {
    width: 150px;
    display: inline;
    margin-bottom: 10px;
}

.enter-input {
    text-align: center;
}

.people {
    margin-bottom: 10px;
}

.form-control.send-input {
    width: 80%;
    display: inline;
    margin-bottom: 10px;
}

.bold {
    font-weight: bold;
}

.visible {
    text-align: center;
    display: block;
    margin-top: 10px;
}

.hidden {
    text-align: center;
    display: none;
}

.alert {
    width:50%;
    margin-left: 25%;
}
