<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <title>ezchat Hub</title>
</head>

<body>
    <h1>ezchat Hub Server</h1>
    <p>Flask server running ezchat hub - based on flask-socketio</p>
    <p>Logging in terminal window</p>
</body>

</html>