@import "../../css/variables.less";

.bold {
    font-weight: bold;
}

.panel-body {
    padding-top: 5px;
    padding-bottom: 5px;
}

.panel-heading {
    padding-top: 5px;
    padding-bottom: 5px;
}

.panel {
    margin-bottom: 10px;
}