body,html{position:relative;background:#eee!important;min-height:100vh}body{padding-bottom:50px}.page-title{position:relative;margin:2rem 0;height:5rem}.page-title h2{position:absolute;left:0;top:0;margin:0;text-transform:uppercase;font-size:3rem;color:#fff;font-weight:200;letter-spacing:.1em;background:#1b6699;padding:1rem 10%}
/*# sourceMappingURL=app-less.css.map*/