@import "variables.less";

/* GLOBAL */
html, body {
    position: relative;
    background: @light-grey !important;
    min-height: 100vh;
}

body {
    padding-bottom: 50px; /* for footer */
}

.page-title {
   /*background: -webkit-linear-gradient(90deg, #1b6699 50%, rgba(255,0,0,0) 50%);
    background: -o-linear-gradient(90deg, #1b6699 50%, rgba(255,0,0,0) 50%);
    background: -moz-linear-gradient(90deg, #1b6699 50%, rgba(255,0,0,0) 50%);
    background: linear-gradient(90deg, #1b6699 50%, rgba(255,0,0,0) 50%);*/
    position: relative;
    margin: 2rem 0 2rem;
    height: 5rem;

    h2 {
        position: absolute;
        left: 0;
        top: 0;
        margin: 0;
        text-transform: uppercase;
        font-size: 3.0rem;
        color: #fff;
        font-weight: 200;
        letter-spacing: 0.1em;
        background: #1b6699;
        padding: 1.0rem 10%;
    }

}


